aboutsummaryrefslogtreecommitdiffstats
path: root/tools/process-x11-xcb.pl
diff options
context:
space:
mode:
authorJeff Morriss <jeff.morriss.ws@gmail.com>2013-11-24 14:27:52 +0000
committerJeff Morriss <jeff.morriss.ws@gmail.com>2013-11-24 14:27:52 +0000
commita98072967ec61c5026e7cac5cb2138be048c0625 (patch)
tree4c625c5a1ff42af18e757ee05ca5f65237df68fb /tools/process-x11-xcb.pl
parent6aec20c782cddca17ad922314d2ca0451e9f351a (diff)
Fix checkAPIs: don't try to feed VALS() into FT_BOOLEANs.
Also, as per Peter Harris' request, update copyright date. svn path=/trunk/; revision=53545
Diffstat (limited to 'tools/process-x11-xcb.pl')
-rwxr-xr-xtools/process-x11-xcb.pl7
1 files changed, 4 insertions, 3 deletions
diff --git a/tools/process-x11-xcb.pl b/tools/process-x11-xcb.pl
index 8b409f0103..7761d87904 100755
--- a/tools/process-x11-xcb.pl
+++ b/tools/process-x11-xcb.pl
@@ -4,7 +4,7 @@
# X11 dissector. Creates header files containing code to
# dissect X11 extensions.
#
-# Copyright 2008, 2009 Open Text Corporation <pharris[AT]opentext.com>
+# Copyright 2008, 2009, 2013 Open Text Corporation <pharris[AT]opentext.com>
#
# $Id$
#
@@ -595,8 +595,9 @@ sub register_element($$$$;$)
my $enumname = dump_enum_values($enum_name{$enum});
$vals = "VALS($enumname)";
# Wireshark does not allow FT_BYTES or BASE_NONE to have an enum
$ft =~ s/FT_BYTES/FT_UINT8/;
+ $ft =~ s/FT_BOOLEAN/FT_UINT8/;
$base =~ s/BASE_NONE/BASE_DEC/;
}
@@ -1572,7 +1573,7 @@ eot
# Add license text
print $out <<eot
/*
- * Copyright 2008, 2009 Open Text Corporation <pharris[AT]opentext.com>
+ * Copyright 2008, 2009, 2013 Open Text Corporation <pharris[AT]opentext.com>
*
* Wireshark - Network traffic analyzer
* By Gerald Combs <gerald[AT]wireshark.org>
@@ -595,8 +595,9 @@ sub register_element($$$$;$)
my $enumname = dump_enum_values($enum_name{$enum});
$vals = "VALS($enumname)";
- # Wireshark does not allow FT_BYTES or BASE_NONE to have an enum
+ # Wireshark does not allow FT_BYTES, FT_BOOLEAN, or BASE_NONE to have an enum
$ft =~ s/FT_BYTES/FT_UINT8/;